@@ -4,5 +4,5 @@ var searchData=
   ['valuenames_1',['valueNames',['../classCppUtilities_1_1Argument.html#a2a8e91b68adaf9c2b744982b5004e1fe',1,'CppUtilities::Argument']]],
   ['values_2',['values',['../classCppUtilities_1_1Argument.html#a68caa6197988491bd53cc63f054d0bc9',1,'CppUtilities::Argument']]],
   ['valuesas_3',['valuesAs',['../classCppUtilities_1_1Argument.html#af35676b4124a851ddd24cfdf26734cd6',1,'CppUtilities::Argument']]],
-  ['verifysignature_4',['verifySignature',['../namespaceCppUtilities.html#aa402c04911a7fe2b025f779fb9dd9486',1,'CppUtilities']]]
+  ['verifysignature_4',['verifySignature',['../namespaceCppUtilities.html#aa402c04911a7fe2b025f779fb9dd9486',1,'CppUtilities::verifySignature(std::string_view publicKeyPem, std::string_view signaturePem, std::string_view data)'],['../namespaceCppUtilities.html#a3def3839cc7c34472a126e167115e1e6',1,'CppUtilities::verifySignature(Keys &amp;&amp;publicKeysPem, std::string_view signaturePem, std::string_view data, VerifyFunction &amp;&amp;verifyFunction=static_cast&lt; MainVerifyFunctionType &gt;(&amp;verifySignature))']]]
 ];
